Exception: AfterDo::CallbackError
- Inherits:
-
StandardError
- Object
- StandardError
- AfterDo::CallbackError
- Defined in:
- lib/after_do.rb
Overview
Raised when an error occurs in one of the callbacks of a method. Provides additional information such as which method and where the block was defined.